==> sandra-web-2.0.0-sources.jar: com/cybelia/sandra/web/action/user/AdminAction.java <==
package com.cybelia.sandra.web.action.user;

import com.cybelia.sandra.entities.Camion;
import com.cybelia.sandra.entities.Chauffeur;
import com.cybelia.sandra.entities.Label;
import com.cybelia.sandra.entities.Transporteur;
import com.cybelia.sandra.entities.UserIndicateurs;
import com.cybelia.sandra.entities.Usine;
import com.cybelia.sandra.entities.notifier.Event;
import com.cybelia.sandra.services.ServiceWeb;
import com.cybelia.sandra.web.action.ApplicationSession;
import com.cybelia.sandra.web.action.CommonMappingDispatchAction;
import com.cybelia.sandra.web.action.ServiceFactory;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.nuiton.topia.taas.entities.TaasUser;

public class AdminAction extends CommonMappingDispatchAction {

    public ActionForward admin(ActionMapping mapping, AdminForm form,
                               HttpServletRequest request, HttpServletResponse response,
                               ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward invalidateCache(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        // Clear all cached entities
        for (ApplicationSession.Cache cache : ApplicationSession.Cache.values()) {
            cache.clear(applicationSession);
        }
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward deleteDuplicatedEtapesAndCreateUniqueIndex(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().deleteDuplicatedEtapesAndCreateUniqueIndex(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward deleteDuplicatedToursAndCreateUniqueIndex(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().deleteDuplicatedToursAndCreateUniqueIndex(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward createAndFillAccessEleveur(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().createAndFillAccessEleveur(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward resetAllUserIndicateurs(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().resetAllUserIndicateurs();

        // Clear cache
        applicationSession.clearNaming(UserIndicateurs.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward updateAllWorstSecurityLevel(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().updateAllWorstSecurityLevel(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward findAndDeleteDuplicateInfoAccess(ActionMapping mapping, AdminForm form,
                                                          HttpServletRequest request, HttpServletResponse response,
                                                          ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().findAndDeleteDuplicateInfoAccess(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward ibu(ActionMapping mapping, AdminForm form,
                             HttpServletRequest request, HttpServletResponse response,
                             ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectIBU(content);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward labels(ActionMapping mapping, AdminForm form,
                                HttpServletRequest request, HttpServletResponse response,
                                ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectLabels(content);

        // Clear cache
        applicationSession.clearNaming(Label.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward usines(ActionMapping mapping, AdminForm form,
                                HttpServletRequest request, HttpServletResponse response,
                                ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectUsines(content);

        // Clear cache
        applicationSession.clearNaming(Usine.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward camions(ActionMapping mapping, AdminForm form,
                                 HttpServletRequest request, HttpServletResponse response,
                                 ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectCamions(content);

        // Clear cache
        applicationSession.clearNaming(Camion.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward chauffeurs(ActionMapping mapping, AdminForm form,
                                    HttpServletRequest request, HttpServletResponse response,
                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectChauffeurs(content);

        // Clear cache
        applicationSession.clearNaming(Chauffeur.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward transporteurs(ActionMapping mapping, AdminForm form,
                                       HttpServletRequest request, HttpServletResponse response,
                                       ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectTransporteurs(content);

        // Clear cache
        applicationSession.clearNaming(Transporteur.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward autorisations(ActionMapping mapping, AdminForm form,
                                       HttpServletRequest request, HttpServletResponse response,
                                       ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectAutorisations(content);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward users(ActionMapping mapping, AdminForm form,
                               HttpServletRequest request, HttpServletResponse response,
                               ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectUsers(content);

        // Clear cache
        applicationSession.clearNaming(TaasUser.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward events(ActionMapping mapping, AdminForm form,
                                HttpServletRequest request, HttpServletResponse response,
                                ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectEvents(content);

        // Clear cache
        applicationSession.clearNaming(Event.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward eleveurGPS(ActionMapping mapping, AdminForm form,
                                    HttpServletRequest request, HttpServletResponse response,
                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectEleveurGPS(content);

        // Clear cache
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward eleveurDuplicated(ActionMapping mapping, AdminForm form,
                                    HttpServletRequest request, HttpServletResponse response,
                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectEleveurDuplicated(content);

        // Clear cache
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }
}

==> sandra-web-2.0.2-sources.jar: com/cybelia/sandra/web/action/user/AdminAction.java <==
package com.cybelia.sandra.web.action.user;

import com.cybelia.sandra.entities.Camion;
import com.cybelia.sandra.entities.Chauffeur;
import com.cybelia.sandra.entities.Label;
import com.cybelia.sandra.entities.Transporteur;
import com.cybelia.sandra.entities.UserIndicateurs;
import com.cybelia.sandra.entities.Usine;
import com.cybelia.sandra.entities.notifier.Event;
import com.cybelia.sandra.services.ServiceWeb;
import com.cybelia.sandra.web.action.ApplicationSession;
import com.cybelia.sandra.web.action.CommonMappingDispatchAction;
import com.cybelia.sandra.web.action.ServiceFactory;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.nuiton.topia.taas.entities.TaasUser;

public class AdminAction extends CommonMappingDispatchAction {

    public ActionForward admin(ActionMapping mapping, AdminForm form,
                               HttpServletRequest request, HttpServletResponse response,
                               ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward invalidateCache(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        // Clear all cached entities
        for (ApplicationSession.Cache cache : ApplicationSession.Cache.values()) {
            cache.clear(applicationSession);
        }
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward createAllActionSecurityForEleveurs(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().createAllActionSecurityForEleveurs(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward createMissingPrincipalsForCamions(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().createMissingPrincipalsForCamions(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward deleteDuplicatedEtapesAndCreateUniqueIndex(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().deleteDuplicatedEtapesAndCreateUniqueIndex(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward deleteDuplicatedToursAndCreateUniqueIndex(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().deleteDuplicatedToursAndCreateUniqueIndex(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward createAndFillAccessEleveur(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().createAndFillAccessEleveur(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward resetAllUserIndicateurs(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().resetAllUserIndicateurs();

        // Clear cache
        applicationSession.clearNaming(UserIndicateurs.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward updateAllWorstSecurityLevel(ActionMapping mapping, AdminForm form,
                                                    HttpServletRequest request, HttpServletResponse response,
                                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().updateAllWorstSecurityLevel(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward findAndDeleteDuplicateInfoAccess(ActionMapping mapping, AdminForm form,
                                                          HttpServletRequest request, HttpServletResponse response,
                                                          ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        ServiceFactory.newServiceWeb().findAndDeleteDuplicateInfoAccess(null);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward ibu(ActionMapping mapping, AdminForm form,
                             HttpServletRequest request, HttpServletResponse response,
                             ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectIBU(content);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward labels(ActionMapping mapping, AdminForm form,
                                HttpServletRequest request, HttpServletResponse response,
                                ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectLabels(content);

        // Clear cache
        applicationSession.clearNaming(Label.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward usines(ActionMapping mapping, AdminForm form,
                                HttpServletRequest request, HttpServletResponse response,
                                ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectUsines(content);

        // Clear cache
        applicationSession.clearNaming(Usine.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward camions(ActionMapping mapping, AdminForm form,
                                 HttpServletRequest request, HttpServletResponse response,
                                 ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectCamions(content);

        // Clear cache
        applicationSession.clearNaming(Camion.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward chauffeurs(ActionMapping mapping, AdminForm form,
                                    HttpServletRequest request, HttpServletResponse response,
                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectChauffeurs(content);

        // Clear cache
        applicationSession.clearNaming(Chauffeur.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward transporteurs(ActionMapping mapping, AdminForm form,
                                       HttpServletRequest request, HttpServletResponse response,
                                       ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectTransporteurs(content);

        // Clear cache
        applicationSession.clearNaming(Transporteur.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward autorisations(ActionMapping mapping, AdminForm form,
                                       HttpServletRequest request, HttpServletResponse response,
                                       ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectAutorisations(content);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward users(ActionMapping mapping, AdminForm form,
                               HttpServletRequest request, HttpServletResponse response,
                               ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectUsers(content);

        // Clear cache
        applicationSession.clearNaming(TaasUser.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward events(ActionMapping mapping, AdminForm form,
                                HttpServletRequest request, HttpServletResponse response,
                                ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectEvents(content);

        // Clear cache
        applicationSession.clearNaming(Event.class);
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward eleveurGPS(ActionMapping mapping, AdminForm form,
                                    HttpServletRequest request, HttpServletResponse response,
                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectEleveurGPS(content);

        // Clear cache
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }

    public ActionForward eleveurDuplicated(ActionMapping mapping, AdminForm form,
                                    HttpServletRequest request, HttpServletResponse response,
                                    ApplicationSession applicationSession, ServiceWeb serviceWeb) throws Exception {

        String content = form.getContent();
        ServiceFactory.newServiceSchedule().injectEleveurDuplicated(content);

        // Clear cache
        form.setContent("");
        return mapping.findForward(SUCCESS_FORWARD);
    }
}
